.. _progguide:

==================
Programmer’s Guide
==================

programming, extending

.. toctree::                                                                    
   :maxdepth: 2  

   progguide/events
   progguide/extensions
   progguide/libraries



